@@ -1,47 +1,19 @@
-from PyQt5.QtWidgets import QMessageBox, QWidget, QComboBox
+from PyQt6.QtWidgets import QMessageBox, QWidget, QComboBox
+from PyQt6.QtCore import Qt, QCoreApplication
 from jdTextEdit.gui.CodeEdit import CodeEdit
-from PyQt5.QtGui import QIcon
+from jdTextEdit.core.Project import Project
+from typing import Dict, Any, Optional
+from PyQt6.QtGui import QIcon
 from pathlib import Path
-from typing import Any, Callable
 import subprocess
-import importlib
-import traceback
 import platform
 import tempfile
-import inspect
 import getpass
+import shutil
 import json
 import sys
 import os
 
-def loadPlugins(path: str,env):
-    """
-    Loads a Plugin for jdTextEdit
-    :param path: plugin
-    :param env: Enviroment
-    """
-    if not os.path.isdir(path):
-        try:
-            os.mkdir(path)
-        except:
-            return
-    pluginlist = os.listdir(path)
-    sys.path.append(path)
-    for i in pluginlist:
-        if i == "__init__.py" or i == "__pycache__":
-            continue
-        try:
-            p = importlib.import_module(i)
-            plugid = p.getID()
-            #Just to make sure these functions exists
-            p.getName()
-            p.getVersion()
-            p.getAuthor()
-            env.plugins[plugid] = p
-            if not plugid in env.settings.disabledPlugins:
-                env.plugins[plugid].main(env)
-        except Exception as e:
-            print(traceback.format_exc(),end="",file=sys.stderr)
 
 def getTemplates(path: str,templatelist: list):
     """
@@ -61,35 +33,60 @@ def getTemplates(path: str,templatelist: list):
         if os.path.isfile(templatePath):
             templatelist.append([i,templatePath])
 
-def executeCommand(command: str,editWidget: CodeEdit,terminal: bool):
+
+def _getSystemTerminalEmulator() -> Optional[str]:
+    """
+    Tries to find a working Terminal Emulator
+    :return:
+    """
+    for i in ("x-terminal-emulator", "konsole", "gnome-terminal", "xterm"):
+        if shutil.which(i) is not None:
+            return i
+    return None
+
+
+def executeCommand(env, command: str,editWidget: CodeEdit,terminal: bool):
     """
     Executes a command. This function is used by the execute menu.
     :param command: the command
     :param editWidget: the edit widget
     :param terminal: I(f set to True, the command will be executed in a terminal emulator
     """
-    command = command.replace("%url%","file://" + editWidget.getFilePath())
-    command = command.replace("%path%",editWidget.getFilePath())
-    command = command.replace("%directory%",os.path.dirname(editWidget.getFilePath()))
-    command = command.replace("%filename%",os.path.basename(editWidget.getFilePath()))
-    command = command.replace("%selection%",editWidget.selectedText())
+    command = command.replace("%url%", "file://" + editWidget.getFilePath())
+    command = command.replace("%path%", editWidget.getFilePath())
+    command = command.replace("%directory%", os.path.dirname(editWidget.getFilePath()))
+    command = command.replace("%filename%", os.path.basename(editWidget.getFilePath()))
+    command = command.replace("%selection%", editWidget.selectedText())
     if terminal:
         if platform.system() == 'Windows':
-            subprocess.Popen(["cmd.exe","/C",command])
+            subprocess.Popen(["cmd.exe", "/C", command])
             pass
         elif platform.system() == 'Darwin':
             #subprocess.call(('open', filepath))
             pass
         elif platform.system() == "Haiku":
-            subprocess.Popen(["/system/apps/Terminal",command])
+            subprocess.Popen(["/system/apps/Terminal", command])
         elif os.getenv("SNAP"):
-            subprocess.Popen([os.path.join(os.getenv("SNAP"),"usr","bin","xterm"),"-e",command])
+            subprocess.Popen([os.path.join(os.getenv("SNAP"), "usr", "bin", "xterm"), "-e", command])
         else:
-            subprocess.Popen(["x-terminal-emulator","-e",command])
+            if env.settings.get("useCustomTerminalEmulator"):
+                try:
+                    subprocess.Popen([env.settings.get("customTerminalEmulator"), "-e", command])
+                except FileNotFoundError:
+                    QMessageBox.critical(None, QCoreApplication.translate("Functions", "Terminal emulator not found"),
+                                         QCoreApplication.translate("Functions", "Your custom terminal emulator was not found"))
+            else:
+                systemEmulator = _getSystemTerminalEmulator()
+                if systemEmulator is None:
+                    QMessageBox.critical(None, QCoreApplication.translate("Functions", "Terminal emulator not found"),
+                                         QCoreApplication.translate("Functions", "The terminal emulator of the system was not found. Try setting a custom one in the Settings."))
+                else:
+                    subprocess.Popen([systemEmulator, "-e", command])
     else:
         os.popen(command)
 
-def getThemeIcon(env,name: str) -> QIcon:
+
+def getThemeIcon(env, name: str) -> QIcon:
     """
     Returns the Icon from Theme. If the Theme doesn't contain the given Icon, it returns the Icon from jdTextEdit.
     :param env: Enviroment
@@ -99,7 +96,8 @@ def getThemeIcon(env,name: str) -> QIcon:
     if QIcon.themeName() and env.settings.useNativeIcons:
         return QIcon.fromTheme(name)
     else:
-        return QIcon(os.path.join(env.programDir,"icons/" + name + ".png"))
+        return QIcon(os.path.join(env.programDir, "icons/" + name + ".png"))
+
 
 def openFileDefault(filepath: str):
     """
@@ -115,6 +113,7 @@ def openFileDefault(filepath: str):
     else:
         subprocess.call(('xdg-open', filepath))
 
+
 def showMessageBox(title: str, text: str):
     """
     Shows a message box.
@@ -124,8 +123,9 @@ def showMessageBox(title: str, text: str):
     messageBox = QMessageBox()
     messageBox.setWindowTitle(title)
     messageBox.setText(text)
-    messageBox.setStandardButtons(QMessageBox.Ok)
-    messageBox.exec_()
+    messageBox.setStandardButtons(QMessageBox.StandardButton.Ok)
+    messageBox.exec()
+
 
 def getDataPath(env) -> str:
     """
@@ -153,7 +153,8 @@ def getDataPath(env) -> str:
         else:
             return os.path.join(str(Path.home()),".local","share","jdTextEdit")
 
-def saveWindowState(window: QWidget,windict: dict,winid: str):
+
+def saveWindowState(window: QWidget, windict: dict, winid: str):
     """
     Saves the state of the Window in the given dict
     :param window: The Window
@@ -161,11 +162,13 @@ def saveWindowState(window: QWidget,windict: dict,winid: str):
     :param winid: The ID of the Window
     """
     windict[winid] = {}
-    x,y,w,h = window.geometry().getRect()
+    x, y, w, h = window.geometry().getRect()
     windict[winid]["x"] = x
     windict[winid]["y"] = y
     windict[winid]["width"] = w
     windict[winid]["height"] = h
+    windict[winid]["maximized"] = window.isMaximized()
+
 
 def restoreWindowState(window: QWidget,windict: dict,winid: str):
     """
@@ -176,6 +179,9 @@ def restoreWindowState(window: QWidget,windict: dict,winid: str):
     """
     if winid in windict:
         window.setGeometry(windict[winid]["x"],windict[winid]["y"],windict[winid]["width"],windict[winid]["height"])
+        if windict.get("maximized", False):
+            window.setWindowState(Qt.WindowStates.WindowMaximized)
+
 
 def getTempOpenFilePath() -> str:
     """
@@ -184,6 +190,7 @@ def getTempOpenFilePath() -> str:
     """
     return os.path.join(tempfile.gettempdir(),"jdTextEdit_" + getpass.getuser() + ".tmp")
 
+
 def selectComboBoxItem(comboBox: QComboBox, item: str):
     """
     Selects the given item in a QComboBox
@@ -194,7 +201,8 @@ def selectComboBoxItem(comboBox: QComboBox, item: str):
         if comboBox.itemText(i) == item:
             comboBox.setCurrentIndex(i)
 
-def readJsonFile(path: str,default) -> Any:
+
+def readJsonFile(path: str, default: Any) -> Any:
     """
     Tries to parse the given JSON file and prints a error if the file couldn't be parsed
     Returns default if the file is not found or couldn't be parsed
@@ -204,18 +212,19 @@ def readJsonFile(path: str,default) -> Any:
     """
     if os.path.isfile(path):
         try:
-            with open(path,"r",encoding="utf-8") as f:
+            with open(path, "r", encoding="utf-8") as f:
                 data = json.load(f)
                 return data
         except json.decoder.JSONDecodeError as e:
-            print(f"Can't parse {os.path.basename(path)}: {e.msg}: line {e.lineno} column {e.colno} (char {e.pos})",file=sys.stderr)
+            print(f"Can't parse {os.path.basename(path)}: {e.msg}: line {e.lineno} column {e.colno} (char {e.pos})", file=sys.stderr)
             return default
         except:
-            print("Can't read " + os.path.basename(path),file=sys.stderr)
+            print("Can't read " + os.path.basename(path), file=sys.stderr)
             return default
     else:
         return default
 
+
 def getFullPath(path: str) -> str:
     """
     Replaces variables and placeholders in path with their values
@@ -224,6 +233,7 @@ def getFullPath(path: str) -> str:
     """
     return os.path.expanduser(os.path.expandvars(path))
 
+
 def isFilenameValid(filename: str) -> bool:
     """
     Checks if a filename contains chars that are used to separate folder e.g. /
@@ -235,3 +245,45 @@ def isFilenameValid(filename: str) -> bool:
         return True
     else:
         return False
+
+
+def saveProjects(projectDict: Dict, path: str):
+    """
+    Saves to projects to a file
+    :param projectDict:
+    :param path:
+    :return:
+    """
+    if len(projectDict) == 0:
+        if os.path.isfile(path):
+            os.remove(path)
+        return
+    saveDict = {}
+    for key, value in projectDict.items():
+        saveDict[key] = {}
+        saveDict[key]["name"] = value.getName()
+        saveDict[key]["path"] = value.getRootDir()
+    with open(path, "w", encoding="utf-8") as f:
+        json.dump(saveDict, f, ensure_ascii=False, indent=4)
+
+
+def loadProjects(env, path: str) -> Dict[str, Project]:
+    """
+    Loads the projetcs from a file
+    :param env:
+    :param path:
+    :return:
+    """
+    data = readJsonFile(path, {})
+    projectDict = {}
+    for key, value in data.items():
+        projectDict[key] = Project(env, key, value["name"], value["path"])
+    return projectDict
+
+
+def isFlatpak() -> bool:
+    """
+    Checks if jdTextEdit runs as Flatpak
+    :return: isFlatpak
+    """
+    return os.path.isdir("/app")
