@@ -1,18 +1,24 @@
-from PyQt5.QtWidgets import QMenu
-from PyQt5.Qsci import QsciScintilla, QsciLexer, QsciScintillaBase, QsciMacro
-from PyQt5.QtGui import QColor, QFontMetrics, QFont, QCursor
-from PyQt5.QtCore import pyqtSignal
+from PyQt6.QtWidgets import QMenu
+from PyQt6.Qsci import QsciScintilla, QsciLexer, QsciScintillaBase, QsciMacro
+from PyQt6.QtGui import QColor, QFontMetrics, QFont, QCursor
+from PyQt6.QtCore import pyqtSignal
 from jdTextEdit.gui.BannerWidgets.EditorconfigBanner import EditorconfigBanner
 from jdTextEdit.api.LanguageBase import LanguageBase
-import editorconfig
 import traceback
 import copy
 import sys
 import os
 
+
+try:
+    import editorconfig
+except ModuleNotFoundError:
+    print("editorconfig module not found", file=sys.stderr)
+
+
 class CodeEdit(QsciScintilla):
     pathChanged = pyqtSignal("QString")
-    def __init__(self,env,preview=None,isNew=False,container=None):
+    def __init__(self, env, preview=None, isNew=False, container=None):
         super().__init__()
         self.env = env
         self.isPreview = preview
@@ -34,8 +40,8 @@ class CodeEdit(QsciScintilla):
         self.currentIdicatorNumber = 0
         self.cursorPosString = env.translate("mainWindow.statusBar.cursorPosLabel") % (1,1)
         self.languageName = env.translate("mainWindow.menu.language.plainText")
-        self.foldStyles = [QsciScintilla.NoFoldStyle,QsciScintilla.PlainFoldStyle,QsciScintilla.CircledFoldStyle,QsciScintilla.BoxedFoldStyle,QsciScintilla.CircledTreeFoldStyle,QsciScintilla.BoxedTreeFoldStyle]
-        eolModeList = [QsciScintilla.EolWindows,QsciScintilla.EolUnix,QsciScintilla.EolMac]
+        self.foldStyles = [QsciScintilla.FoldStyle.NoFoldStyle,QsciScintilla.FoldStyle.PlainFoldStyle,QsciScintilla.FoldStyle.CircledFoldStyle,QsciScintilla.FoldStyle.BoxedFoldStyle,QsciScintilla.FoldStyle.CircledTreeFoldStyle,QsciScintilla.FoldStyle.BoxedTreeFoldStyle]
+        eolModeList = [QsciScintilla.EolMode.EolWindows,QsciScintilla.EolMode.EolUnix,QsciScintilla.EolMode.EolMac]
         self.changeEolMode(eolModeList[self.settings.defaultEolMode])
         self.updateSettings(self.settings)
         self.setMarginLineNumbers(0, True)
@@ -45,7 +51,7 @@ class CodeEdit(QsciScintilla):
         self.setMarginSensitivity(1,True)
         #self.modificationStateChange(False)
         #self.setMarginsBackgroundColor(QColor("#cccccc"))
-        #self.setWrapVisualFlags(QsciScintilla.WrapFlagByText)
+        #self.setWrapVisualFlags(QsciScintilla.WrapVisualFlag.WrapFlagByText)
 
         self.textChanged.connect(self.textEdited)
         self.selectionChanged.connect(self.editSelectionChanged)
@@ -61,8 +67,8 @@ class CodeEdit(QsciScintilla):
                 if l.getID() == self.settings.defaultLanguage:
                     self.setLanguage(l)
 
-        self.setMarginType(1, QsciScintilla.SymbolMargin)
-        sym_4 = QsciScintilla.Circle
+        self.setMarginType(1, QsciScintilla.MarginType.SymbolMargin)
+        sym_4 = QsciScintilla.MarkerSymbol.Circle
         self.markerDefine(sym_4, 0)
         #self.setMarginWidth(1, 10)
 
@@ -77,11 +83,11 @@ class CodeEdit(QsciScintilla):
         self.env.mainWindow.encodingLabel.setText(self.usedEncoding)
         self.env.mainWindow.lexerLabel.setText(self.languageName)
         self.env.mainWindow.cursorPosLabel.setText(self.cursorPosString)
-        if self.eolMode() == QsciScintilla.EolWindows:
+        if self.eolMode() == QsciScintilla.EolMode.EolWindows:
             self.env.mainWindow.eolLabel.setText("CRLF")
-        elif self.eolMode() == QsciScintilla.EolUnix:
+        elif self.eolMode() == QsciScintilla.EolMode.EolUnix:
             self.env.mainWindow.eolLabel.setText("LF")
-        elif self.eolMode() == QsciScintilla.EolMac:
+        elif self.eolMode() == QsciScintilla.EolMode.EolMac:
             self.env.mainWindow.eolLabel.setText("CR")
 
     def setLanguage(self,lang: LanguageBase):
@@ -187,11 +193,11 @@ class CodeEdit(QsciScintilla):
         self.env.mainWindow.eolModeWindows.setChecked(False)
         self.env.mainWindow.eolModeUnix.setChecked(False)
         self.env.mainWindow.eolModeMac.setChecked(False)
-        if self.eolMode() == QsciScintilla.EolWindows:
+        if self.eolMode() == QsciScintilla.EolMode.EolWindows:
             self.env.mainWindow.eolModeWindows.setChecked(True)
-        elif self.eolMode() == QsciScintilla.EolUnix:
+        elif self.eolMode() == QsciScintilla.EolMode.EolUnix:
             self.env.mainWindow.eolModeUnix.setChecked(True)
-        elif self.eolMode() == QsciScintilla.EolMac:
+        elif self.eolMode() == QsciScintilla.EolMode.EolMac:
             self.env.mainWindow.eolModeMac.setChecked(True)
 
     def changeEolMode(self, mode):
@@ -201,11 +207,11 @@ class CodeEdit(QsciScintilla):
         self.updateStatusBar()
 
     def getEolChar(self):
-        if self.eolMode() == QsciScintilla.EolWindows:
+        if self.eolMode() == QsciScintilla.EolMode.EolWindows:
             return "\r\n"
-        elif self.eolMode() == QsciScintilla.EolUnix:
+        elif self.eolMode() == QsciScintilla.EolMode.EolUnix:
             return "\n"
-        elif self.eolMode() == QsciScintilla.EolMac:
+        elif self.eolMode() == QsciScintilla.EolMode.EolMac:
             return "\r"
 
     def setUsedEncoding(self, encoding):
@@ -313,14 +319,14 @@ class CodeEdit(QsciScintilla):
         self.setFilePath(path)
         self.setModified(data["modified"])
         self.setUsedEncoding(data.get("encoding",self.settings.defaultEncoding))
-        syntax = data.get("language","")
+        syntax = data.get("language", "")
         if syntax != "":
             for l in self.env.languageList:
                 if  l.getID() == syntax:
                     self.setLanguage(l)
         self.bookmarkList = data.get("bookmarks",[])
         for line in self.bookmarkList:
-            self.markerAdd(line,0)
+            self.markerAdd(line, 0)
         self.setCursorPosition(data["cursorPosLine"],data["cursorPosIndex"])
         self.zoomTo(data.get("zoom",self.settings.defaultZoom))
         self.custom_settings = data.get("customSettings",{})
@@ -345,8 +351,11 @@ class CodeEdit(QsciScintilla):
         """
         try:
             config = editorconfig.get_properties(self.getFilePath())
-        except:
-            print("Error occurred while getting .editorconfig properties")
+        except NameError:
+            print("Trying to load a file with editorconfig enabled while the editorconfig module is not installed", file=sys.stderr)
+            return
+        except Exception:
+            print("Error occurred while getting .editorconfig properties", file=sys.stderr)
             return
         if "indent_style" in config and self.settings.editorConfigUseIndentStyle:
             if config["indent_style"] == "space":
@@ -387,9 +396,8 @@ class CodeEdit(QsciScintilla):
         self.setMarginsFont(font)
         fontmetrics = QFontMetrics(font)
         if settings.editShowLineNumbers:
-            self.setMarginWidth(0, fontmetrics.width("00000") + 6)
+            self.setMarginWidth(0, fontmetrics.averageCharWidth() * 6)
         else:
-            pass
             self.setMarginWidth(0,0)
         if self.currentLexer:
             self.currentLexer.setFont(font)
@@ -406,7 +414,7 @@ class CodeEdit(QsciScintilla):
             try:
                 self.env.themes[settings.editTheme].applyTheme(self,self.currentLexer)
             except Exception as e:
-                print(traceback.format_exc(),end="",file=sys.stderr)
+                print(traceback.format_exc(), end="", file=sys.stderr)
                 self.env.themes["builtin.default"].applyTheme(self, self.currentLexer)
         else:
             print("The selected Theme could not be found. Falling back to the default Theme.",file=sys.stderr)
@@ -419,20 +427,26 @@ class CodeEdit(QsciScintilla):
         self.setCaretLineVisible(settings.highlightCurrentLine)
         self.setTabWidth(settings.editTabWidth)
         self.setIndentationsUseTabs(not settings.editTabSpaces)
-        self.setWrapMode(settings.editTextWrap)
-        self.setWhitespaceVisibility(settings.editShowWhitespaces)
+        if settings.get("editTextWrap"):
+            self.setWrapMode(QsciScintilla.WrapMode.WrapWord)
+        else:
+            self.setWrapMode(QsciScintilla.WrapMode.WrapNone)
+        if settings.get("editShowWhitespaces"):
+            self.setWhitespaceVisibility(QsciScintilla.WhitespaceVisibility.WsVisible)
+        else:
+            self.setWhitespaceVisibility(QsciScintilla.WhitespaceVisibility.WsInvisible)
         self.setAutoIndent(settings.editAutoIndent)
         self.setEolVisibility(settings.editShowEol)
         self.setIndentationGuides(settings.showIndentationGuides)
         if settings.enableAutocompletion:
             if settings.autocompletionUseDocument and settings.autocompletionUseAPI:
-                self.setAutoCompletionSource(QsciScintilla.AcsAll)
+                self.setAutoCompletionSource(QsciScintilla.AutoCompletionSource.AcsAll)
             elif settings.autocompletionUseDocument:
-                self.setAutoCompletionSource(QsciScintilla.AcsDocument)
+                self.setAutoCompletionSource(QsciScintilla.AutoCompletionSource.AcsDocument)
             elif settings.autocompletionUseAPI:
-                self.setAutoCompletionSource(QsciScintilla.AcsAPIs)
+                self.setAutoCompletionSource(QsciScintilla.AutoCompletionSource.AcsAPIs)
             else:
-                self.setAutoCompletionSource(QsciScintilla.AcsNone)
+                self.setAutoCompletionSource(QsciScintilla.AutoCompletionSource.AcsNone)
             self.setAutoCompletionCaseSensitivity(settings.autocompletionCaseSensitive)
             self.setAutoCompletionThreshold(settings.autocompleteThreshold)
             self.setAutoCompletionReplaceWord(settings.autocompletionReplaceWord)
@@ -445,7 +459,7 @@ class CodeEdit(QsciScintilla):
                 #else:
                     #api = self.apiCompletion(self.currentLexer)
         else:
-            self.setAutoCompletionSource(QsciScintilla.AcsNone)
+            self.setAutoCompletionSource(QsciScintilla.AutoCompletionSource.AcsNone)
         self.settings = settings
 
     def positionFromPoint(self,point):
@@ -488,4 +502,4 @@ class CodeEdit(QsciScintilla):
             return
         self.container.getTabWidget().markWidgetAsActive()
         self.updateOtherWidgets()
-        super().focusInEvent(event)
\ No newline at end of file
+        super().focusInEvent(event)
