@@ -1,5 +1,5 @@
-from PyQt5.QtWidgets import QApplication, QWidget, QLineEdit, QPushButton, QLabel, QHBoxLayout, QVBoxLayout, QLayout
-from PyQt5.QtGui import QIntValidator
+from PyQt6.QtWidgets import QApplication, QWidget, QLineEdit, QPushButton, QLabel, QHBoxLayout, QVBoxLayout, QLayout
+from PyQt6.QtGui import QIntValidator
 
 class GotoLineWindow(QWidget):
     def __init__(self, env):
@@ -7,7 +7,7 @@ class GotoLineWindow(QWidget):
         self.lineEdit = QLineEdit()
         okButton = QPushButton(env.translate("button.ok"))
         cancelButton = QPushButton(env.translate("button.cancel"))
-        
+
         self.lineEdit.setValidator(QIntValidator())
         okButton.clicked.connect(self.okButtonClicked)
         cancelButton.clicked.connect(self.close)
@@ -21,8 +21,8 @@ class GotoLineWindow(QWidget):
         mainLayout.addWidget(QLabel(env.translate("gotoLineWindow.text")))
         mainLayout.addWidget(self.lineEdit)
         mainLayout.addLayout(buttonLayout)
-        mainLayout.setSizeConstraint(QLayout.SetFixedSize)
-        
+        mainLayout.setSizeConstraint(QLayout.SizeConstraint.SetFixedSize)
+
         self.setLayout(mainLayout)
         self.setWindowTitle(env.translate("gotoLineWindow.title"))
 
@@ -34,7 +34,7 @@ class GotoLineWindow(QWidget):
 
     def okButtonClicked(self):
         try:
-            self.editWidget.setCursorPosition(int(self.lineEdit.text()) - 1,0)
+            self.editWidget.setCursorPosition(int(self.lineEdit.text()) - 1, 0)
             self.editWidget.ensureCursorVisible()
         except:
             pass
